
import json
import pandas as pd
from foglamp.plugins.filter.ADM_LD_prediction.constants import LOGLEVEL


def parse_config(plugin_config):
    """Plugin configuration parser."""
    bucket_config = json.loads(plugin_config["bucketConfig"]["value"])

    _sampling_rate = plugin_config["samplingRate"]["value"]
    _sampling_rate = (
        (int(_sampling_rate[:-3]) * 1000)
        if _sampling_rate.endswith("khz") else
        int(_sampling_rate)
    )

    module_config = {
        "inputs": {
            "asset": plugin_config["timeseriesAsset"]["value"],
            "sampling_rate": _sampling_rate,
        },
        "inference": {
            "use_tpu": plugin_config["enableTpu"]["value"] == "true",
            "model_type": plugin_config["modelType"]["value"],
            "ts_col": plugin_config["tsCol"]["value"],
            "sensor_cols": plugin_config["useCols"]["value"].split(","),
            "trigger_interval": pd.to_timedelta(
                plugin_config["evaluationInterval"]["value"]
            ),
            "bucket": {
                "bucket_type": bucket_config["type"],
                "model_name": bucket_config["name"],
                "model_version": bucket_config["version"],
            }
        },
        "post_process": {
            "num_evaluation": plugin_config["numEvaluations"]["value"],
            "num_anomaly": plugin_config["numAnomalies"]["value"]
        },
        "output": {
            "asset": plugin_config["centrifugeHealthAsset"]["value"],
            "forward_data": plugin_config["forwardData"]["value"] == "true",
        },
        "log_level": LOGLEVEL[plugin_config["logLevel"]["value"]],
        "enabled": plugin_config["enable"]["value"] == "true"
    }
    del plugin_config

    return module_config
